You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@wicket.apache.org by jc...@apache.org on 2007/04/10 20:54:58 UTC

svn commit: r527247 [3/8] - in /incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src: main/java/ main/java/org/ main/java/org/apache/ main/java/org/apache/wicket/ main/java/org/apache/wicket/authentication/ main/java/org/apache/wicket/authe...

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/ajax/builtin/tree/ModelBean.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/ajax/builtin/tree/ModelBean.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/ajax/builtin/tree/ModelBean.java?view=diff&rev=527247&p1=incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/ajax/builtin/tree/ModelBean.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/ajax/builtin/tree/ModelBean.java&r2=527247
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/ajax/builtin/tree/ModelBean.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/ajax/builtin/tree/ModelBean.java Tue Apr 10 11:54:24 2007
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.examples.ajax.builtin.tree;
+package org.apache.wicket.examples.ajax.builtin.tree;
 
 import java.io.Serializable;
 

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/ajax/builtin/tree/PropertyEditableColumn.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/ajax/builtin/tree/PropertyEditableColumn.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/ajax/builtin/tree/PropertyEditableColumn.java?view=diff&rev=527247&p1=incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/ajax/builtin/tree/PropertyEditableColumn.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/ajax/builtin/tree/PropertyEditableColumn.java&r2=527247
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/ajax/builtin/tree/PropertyEditableColumn.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/ajax/builtin/tree/PropertyEditableColumn.java Tue Apr 10 11:54:24 2007
@@ -14,17 +14,18 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.examples.ajax.builtin.tree;
+package org.apache.wicket.examples.ajax.builtin.tree;
 
 import javax.swing.tree.TreeNode;
 
-import wicket.Component;
-import wicket.MarkupContainer;
-import wicket.extensions.markup.html.tree.table.ColumnLocation;
-import wicket.extensions.markup.html.tree.table.IColumn;
-import wicket.extensions.markup.html.tree.table.IRenderable;
-import wicket.extensions.markup.html.tree.table.PropertyRenderableColumn;
-import wicket.model.PropertyModel;
+import org.apache.wicket.Component;
+import org.apache.wicket.MarkupContainer;
+import org.apache.wicket.extensions.markup.html.tree.table.ColumnLocation;
+import org.apache.wicket.extensions.markup.html.tree.table.IColumn;
+import org.apache.wicket.extensions.markup.html.tree.table.IRenderable;
+import org.apache.wicket.extensions.markup.html.tree.table.PropertyRenderableColumn;
+import org.apache.wicket.model.PropertyModel;
+
 
 /**
  * Column, that either shows a readonly cell or an editable panel, depending on whether

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/ajax/builtin/tree/SimpleTreePage.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/ajax/builtin/tree/SimpleTreePage.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/ajax/builtin/tree/SimpleTreePage.java?view=diff&rev=527247&p1=incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/ajax/builtin/tree/SimpleTreePage.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/ajax/builtin/tree/SimpleTreePage.java&r2=527247
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/ajax/builtin/tree/SimpleTreePage.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/ajax/builtin/tree/SimpleTreePage.java Tue Apr 10 11:54:24 2007
@@ -14,13 +14,14 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.examples.ajax.builtin.tree;
+package org.apache.wicket.examples.ajax.builtin.tree;
 
 import javax.swing.tree.DefaultMutableTreeNode;
 import javax.swing.tree.TreeNode;
 
-import wicket.extensions.markup.html.tree.AbstractTree;
-import wicket.extensions.markup.html.tree.Tree;
+import org.apache.wicket.extensions.markup.html.tree.AbstractTree;
+import org.apache.wicket.extensions.markup.html.tree.Tree;
+
 
 /**
  * Page that shuws a simple tree (not a table).

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/ajax/builtin/tree/TreeTablePage.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/ajax/builtin/tree/TreeTablePage.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/ajax/builtin/tree/TreeTablePage.java?view=diff&rev=527247&p1=incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/ajax/builtin/tree/TreeTablePage.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/ajax/builtin/tree/TreeTablePage.java&r2=527247
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/ajax/builtin/tree/TreeTablePage.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/ajax/builtin/tree/TreeTablePage.java Tue Apr 10 11:54:24 2007
@@ -14,16 +14,16 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.examples.ajax.builtin.tree;
+package org.apache.wicket.examples.ajax.builtin.tree;
 
-import wicket.extensions.markup.html.tree.AbstractTree;
-import wicket.extensions.markup.html.tree.table.ColumnLocation;
-import wicket.extensions.markup.html.tree.table.IColumn;
-import wicket.extensions.markup.html.tree.table.PropertyRenderableColumn;
-import wicket.extensions.markup.html.tree.table.PropertyTreeColumn;
-import wicket.extensions.markup.html.tree.table.TreeTable;
-import wicket.extensions.markup.html.tree.table.ColumnLocation.Alignment;
-import wicket.extensions.markup.html.tree.table.ColumnLocation.Unit;
+import org.apache.wicket.extensions.markup.html.tree.AbstractTree;
+import org.apache.wicket.extensions.markup.html.tree.table.ColumnLocation;
+import org.apache.wicket.extensions.markup.html.tree.table.IColumn;
+import org.apache.wicket.extensions.markup.html.tree.table.PropertyRenderableColumn;
+import org.apache.wicket.extensions.markup.html.tree.table.PropertyTreeColumn;
+import org.apache.wicket.extensions.markup.html.tree.table.TreeTable;
+import org.apache.wicket.extensions.markup.html.tree.table.ColumnLocation.Alignment;
+import org.apache.wicket.extensions.markup.html.tree.table.ColumnLocation.Unit;
 
 /**
  * Page that shows a simple tree table.

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/ajax/prototype/Index.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/ajax/prototype/Index.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/ajax/prototype/Index.java?view=diff&rev=527247&p1=incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/ajax/prototype/Index.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/ajax/prototype/Index.java&r2=527247
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/ajax/prototype/Index.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/ajax/prototype/Index.java Tue Apr 10 11:54:24 2007
@@ -14,15 +14,16 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.examples.ajax.prototype;
+package org.apache.wicket.examples.ajax.prototype;
+
+import org.apache.wicket.examples.WicketExamplePage;
+import org.apache.wicket.markup.html.basic.Label;
+import org.apache.wicket.markup.html.link.ILinkListener;
+import org.apache.wicket.markup.html.link.Link;
+import org.apache.wicket.model.PropertyModel;
+import org.apache.wicket.request.target.component.ComponentRequestTarget;
+import org.apache.wicket.util.string.AppendingStringBuffer;
 
-import wicket.examples.WicketExamplePage;
-import wicket.markup.html.basic.Label;
-import wicket.markup.html.link.ILinkListener;
-import wicket.markup.html.link.Link;
-import wicket.model.PropertyModel;
-import wicket.request.target.component.ComponentRequestTarget;
-import wicket.util.string.AppendingStringBuffer;
 
 /**
  * Example displaying partial page rendering using the counting link example and

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/ajax/prototype/PrototypeApplication.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/ajax/prototype/PrototypeApplication.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/ajax/prototype/PrototypeApplication.java?view=diff&rev=527247&p1=incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/ajax/prototype/PrototypeApplication.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/ajax/prototype/PrototypeApplication.java&r2=527247
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/ajax/prototype/PrototypeApplication.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/ajax/prototype/PrototypeApplication.java Tue Apr 10 11:54:24 2007
@@ -14,10 +14,11 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.examples.ajax.prototype;
+package org.apache.wicket.examples.ajax.prototype;
+
+import org.apache.wicket.examples.WicketExampleApplication;
+import org.apache.wicket.markup.html.AjaxServerAndClientTimeFilter;
 
-import wicket.examples.WicketExampleApplication;
-import wicket.markup.html.AjaxServerAndClientTimeFilter;
 
 /**
  * Application object for the Prototype.js ajax demo page.
@@ -34,7 +35,7 @@
 	}
 
 	/**
-	 * @see wicket.examples.WicketExampleApplication#init()
+	 * @see org.apache.wicket.examples.WicketExampleApplication#init()
 	 */
 	protected void init()
 	{
@@ -43,7 +44,7 @@
 	}
 
 	/**
-	 * @see wicket.Application#getHomePage()
+	 * @see org.apache.wicket.Application#getHomePage()
 	 */
 	public Class getHomePage()
 	{

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/breadcrumb/BreadCrumbApplication.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/breadcrumb/BreadCrumbApplication.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/breadcrumb/BreadCrumbApplication.java?view=diff&rev=527247&p1=incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/breadcrumb/BreadCrumbApplication.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/breadcrumb/BreadCrumbApplication.java&r2=527247
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/breadcrumb/BreadCrumbApplication.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/breadcrumb/BreadCrumbApplication.java Tue Apr 10 11:54:24 2007
@@ -14,9 +14,9 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.examples.breadcrumb;
+package org.apache.wicket.examples.breadcrumb;
 
-import wicket.protocol.http.WebApplication;
+import org.apache.wicket.protocol.http.WebApplication;
 
 /**
  * Application class for the bread crumb example.
@@ -26,7 +26,7 @@
 public class BreadCrumbApplication extends WebApplication
 {
 	/**
-	 * @see wicket.Application#getHomePage()
+	 * @see org.apache.wicket.Application#getHomePage()
 	 */
 	public Class getHomePage()
 	{

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/breadcrumb/FirstPanel.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/breadcrumb/FirstPanel.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/breadcrumb/FirstPanel.java?view=diff&rev=527247&p1=incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/breadcrumb/FirstPanel.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/breadcrumb/FirstPanel.java&r2=527247
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/breadcrumb/FirstPanel.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/breadcrumb/FirstPanel.java Tue Apr 10 11:54:24 2007
@@ -14,11 +14,11 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.examples.breadcrumb;
+package org.apache.wicket.examples.breadcrumb;
 
-import wicket.extensions.breadcrumb.IBreadCrumbModel;
-import wicket.extensions.breadcrumb.panel.BreadCrumbPanel;
-import wicket.extensions.breadcrumb.panel.BreadCrumbPanelLink;
+import org.apache.wicket.extensions.breadcrumb.IBreadCrumbModel;
+import org.apache.wicket.extensions.breadcrumb.panel.BreadCrumbPanel;
+import org.apache.wicket.extensions.breadcrumb.panel.BreadCrumbPanelLink;
 
 /**
  * Test bread crumb enabled panel.
@@ -40,7 +40,7 @@
 	}
 
 	/**
-	 * @see wicket.extensions.breadcrumb.IBreadCrumbParticipant#getTitle()
+	 * @see org.apache.wicket.extensions.breadcrumb.IBreadCrumbParticipant#getTitle()
 	 */
 	public String getTitle()
 	{

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/breadcrumb/FourthPanel.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/breadcrumb/FourthPanel.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/breadcrumb/FourthPanel.java?view=diff&rev=527247&p1=incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/breadcrumb/FourthPanel.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/breadcrumb/FourthPanel.java&r2=527247
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/breadcrumb/FourthPanel.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/breadcrumb/FourthPanel.java Tue Apr 10 11:54:24 2007
@@ -14,10 +14,10 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.examples.breadcrumb;
+package org.apache.wicket.examples.breadcrumb;
 
-import wicket.extensions.breadcrumb.IBreadCrumbModel;
-import wicket.extensions.breadcrumb.panel.BreadCrumbPanel;
+import org.apache.wicket.extensions.breadcrumb.IBreadCrumbModel;
+import org.apache.wicket.extensions.breadcrumb.panel.BreadCrumbPanel;
 
 /**
  * Test bread crumb enabled panel.
@@ -38,7 +38,7 @@
 	}
 
 	/**
-	 * @see wicket.extensions.breadcrumb.IBreadCrumbParticipant#getTitle()
+	 * @see org.apache.wicket.extensions.breadcrumb.IBreadCrumbParticipant#getTitle()
 	 */
 	public String getTitle()
 	{

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/breadcrumb/Index.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/breadcrumb/Index.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/breadcrumb/Index.java?view=diff&rev=527247&p1=incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/breadcrumb/Index.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/breadcrumb/Index.java&r2=527247
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/breadcrumb/Index.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/breadcrumb/Index.java Tue Apr 10 11:54:24 2007
@@ -14,10 +14,11 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.examples.breadcrumb;
+package org.apache.wicket.examples.breadcrumb;
+
+import org.apache.wicket.examples.WicketExamplePage;
+import org.apache.wicket.extensions.breadcrumb.BreadCrumbBar;
 
-import wicket.examples.WicketExamplePage;
-import wicket.extensions.breadcrumb.BreadCrumbBar;
 
 /**
  * Index page for the bread crumb example.

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/breadcrumb/ResultPanel.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/breadcrumb/ResultPanel.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/breadcrumb/ResultPanel.java?view=diff&rev=527247&p1=incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/breadcrumb/ResultPanel.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/breadcrumb/ResultPanel.java&r2=527247
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/breadcrumb/ResultPanel.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/breadcrumb/ResultPanel.java Tue Apr 10 11:54:24 2007
@@ -14,11 +14,12 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.examples.breadcrumb;
+package org.apache.wicket.examples.breadcrumb;
+
+import org.apache.wicket.extensions.breadcrumb.IBreadCrumbModel;
+import org.apache.wicket.extensions.breadcrumb.panel.BreadCrumbPanel;
+import org.apache.wicket.markup.html.basic.Label;
 
-import wicket.extensions.breadcrumb.IBreadCrumbModel;
-import wicket.extensions.breadcrumb.panel.BreadCrumbPanel;
-import wicket.markup.html.basic.Label;
 
 /**
  * Test bread crumb enabled panel.
@@ -48,7 +49,7 @@
 	}
 
 	/**
-	 * @see wicket.extensions.breadcrumb.IBreadCrumbParticipant#getTitle()
+	 * @see org.apache.wicket.extensions.breadcrumb.IBreadCrumbParticipant#getTitle()
 	 */
 	public String getTitle()
 	{

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/breadcrumb/SecondPanel.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/breadcrumb/SecondPanel.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/breadcrumb/SecondPanel.java?view=diff&rev=527247&p1=incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/breadcrumb/SecondPanel.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/breadcrumb/SecondPanel.java&r2=527247
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/breadcrumb/SecondPanel.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/breadcrumb/SecondPanel.java Tue Apr 10 11:54:24 2007
@@ -14,16 +14,17 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.examples.breadcrumb;
+package org.apache.wicket.examples.breadcrumb;
+
+import org.apache.wicket.extensions.breadcrumb.IBreadCrumbModel;
+import org.apache.wicket.extensions.breadcrumb.panel.BreadCrumbPanel;
+import org.apache.wicket.extensions.breadcrumb.panel.BreadCrumbPanelLink;
+import org.apache.wicket.extensions.breadcrumb.panel.IBreadCrumbPanelFactory;
+import org.apache.wicket.markup.html.form.Button;
+import org.apache.wicket.markup.html.form.Form;
+import org.apache.wicket.markup.html.form.TextField;
+import org.apache.wicket.model.CompoundPropertyModel;
 
-import wicket.extensions.breadcrumb.IBreadCrumbModel;
-import wicket.extensions.breadcrumb.panel.BreadCrumbPanel;
-import wicket.extensions.breadcrumb.panel.BreadCrumbPanelLink;
-import wicket.extensions.breadcrumb.panel.IBreadCrumbPanelFactory;
-import wicket.markup.html.form.Button;
-import wicket.markup.html.form.Form;
-import wicket.markup.html.form.TextField;
-import wicket.model.CompoundPropertyModel;
 
 /**
  * Test bread crumb enabled panel.
@@ -106,7 +107,7 @@
 	}
 
 	/**
-	 * @see wicket.extensions.breadcrumb.IBreadCrumbParticipant#getTitle()
+	 * @see org.apache.wicket.extensions.breadcrumb.IBreadCrumbParticipant#getTitle()
 	 */
 	public String getTitle()
 	{

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/breadcrumb/ThirdPanel.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/breadcrumb/ThirdPanel.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/breadcrumb/ThirdPanel.java?view=diff&rev=527247&p1=incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/breadcrumb/ThirdPanel.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/breadcrumb/ThirdPanel.java&r2=527247
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/breadcrumb/ThirdPanel.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/breadcrumb/ThirdPanel.java Tue Apr 10 11:54:24 2007
@@ -14,10 +14,10 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.examples.breadcrumb;
+package org.apache.wicket.examples.breadcrumb;
 
-import wicket.extensions.breadcrumb.IBreadCrumbModel;
-import wicket.extensions.breadcrumb.panel.BreadCrumbPanel;
+import org.apache.wicket.extensions.breadcrumb.IBreadCrumbModel;
+import org.apache.wicket.extensions.breadcrumb.panel.BreadCrumbPanel;
 
 /**
  * Test bread crumb enabled panel.
@@ -38,7 +38,7 @@
 	}
 
 	/**
-	 * @see wicket.extensions.breadcrumb.IBreadCrumbParticipant#getTitle()
+	 * @see org.apache.wicket.extensions.breadcrumb.IBreadCrumbParticipant#getTitle()
 	 */
 	public String getTitle()
 	{

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/captcha/Captcha.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/captcha/Captcha.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/captcha/Captcha.java?view=diff&rev=527247&p1=incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/captcha/Captcha.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/captcha/Captcha.java&r2=527247
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/captcha/Captcha.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/captcha/Captcha.java Tue Apr 10 11:54:24 2007
@@ -14,18 +14,19 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.examples.captcha;
+package org.apache.wicket.examples.captcha;
+
+import org.apache.wicket.PageParameters;
+import org.apache.wicket.examples.WicketExamplePage;
+import org.apache.wicket.extensions.markup.html.captcha.CaptchaImageResource;
+import org.apache.wicket.markup.ComponentTag;
+import org.apache.wicket.markup.html.form.Form;
+import org.apache.wicket.markup.html.form.RequiredTextField;
+import org.apache.wicket.markup.html.image.Image;
+import org.apache.wicket.markup.html.panel.FeedbackPanel;
+import org.apache.wicket.model.PropertyModel;
+import org.apache.wicket.util.value.ValueMap;
 
-import wicket.PageParameters;
-import wicket.examples.WicketExamplePage;
-import wicket.extensions.markup.html.captcha.CaptchaImageResource;
-import wicket.markup.ComponentTag;
-import wicket.markup.html.form.Form;
-import wicket.markup.html.form.RequiredTextField;
-import wicket.markup.html.image.Image;
-import wicket.markup.html.panel.FeedbackPanel;
-import wicket.model.PropertyModel;
-import wicket.util.value.ValueMap;
 
 /**
  * Captcha example page.
@@ -63,7 +64,7 @@
 		}
 
 		/**
-		 * @see wicket.markup.html.form.Form#onSubmit()
+		 * @see org.apache.wicket.markup.html.form.Form#onSubmit()
 		 */
 		public void onSubmit()
 		{

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/captcha/CaptchaApplication.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/captcha/CaptchaApplication.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/captcha/CaptchaApplication.java?view=diff&rev=527247&p1=incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/captcha/CaptchaApplication.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/captcha/CaptchaApplication.java&r2=527247
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/captcha/CaptchaApplication.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/captcha/CaptchaApplication.java Tue Apr 10 11:54:24 2007
@@ -14,9 +14,9 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.examples.captcha;
+package org.apache.wicket.examples.captcha;
 
-import wicket.examples.WicketExampleApplication;
+import org.apache.wicket.examples.WicketExampleApplication;
 
 /**
  * Application class for the captcha example.
@@ -33,7 +33,7 @@
 	}
 
 	/**
-	 * @see wicket.Application#getHomePage()
+	 * @see org.apache.wicket.Application#getHomePage()
 	 */
 	public Class getHomePage()
 	{

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/compref/Address.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/compref/Address.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/compref/Address.java?view=diff&rev=527247&p1=incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/compref/Address.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/compref/Address.java&r2=527247
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/compref/Address.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/compref/Address.java Tue Apr 10 11:54:24 2007
@@ -14,9 +14,9 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.examples.compref;
+package org.apache.wicket.examples.compref;
 
-import wicket.IClusterable;
+import org.apache.wicket.IClusterable;
 
 /**
  * An address.

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/compref/AnotherPanel.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/compref/AnotherPanel.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/compref/AnotherPanel.java?view=diff&rev=527247&p1=incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/compref/AnotherPanel.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/compref/AnotherPanel.java&r2=527247
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/compref/AnotherPanel.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/compref/AnotherPanel.java Tue Apr 10 11:54:24 2007
@@ -14,9 +14,9 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.examples.compref;
+package org.apache.wicket.examples.compref;
 
-import wicket.markup.html.panel.Panel;
+import org.apache.wicket.markup.html.panel.Panel;
 
 /**
  * Another sample panel component.

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/compref/Book.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/compref/Book.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/compref/Book.java?view=diff&rev=527247&p1=incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/compref/Book.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/compref/Book.java&r2=527247
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/compref/Book.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/compref/Book.java Tue Apr 10 11:54:24 2007
@@ -14,9 +14,9 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.examples.compref;
+package org.apache.wicket.examples.compref;
 
-import wicket.IClusterable;
+import org.apache.wicket.IClusterable;
 
 /**
  * A book.

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/compref/BookmarkablePage.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/compref/BookmarkablePage.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/compref/BookmarkablePage.java?view=diff&rev=527247&p1=incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/compref/BookmarkablePage.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/compref/BookmarkablePage.java&r2=527247
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/compref/BookmarkablePage.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/compref/BookmarkablePage.java Tue Apr 10 11:54:24 2007
@@ -14,17 +14,17 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.examples.compref;
+package org.apache.wicket.examples.compref;
 
-import wicket.PageParameters;
-import wicket.markup.html.WebPage;
-import wicket.markup.html.basic.Label;
-import wicket.markup.html.link.BookmarkablePageLink;
+import org.apache.wicket.PageParameters;
+import org.apache.wicket.markup.html.WebPage;
+import org.apache.wicket.markup.html.basic.Label;
+import org.apache.wicket.markup.html.link.BookmarkablePageLink;
 
 /**
  * Example page that cannot be bookmarked. A page is bookmarkable when it has a
  * public default constructor and/or a public constructor with a
- * {@link wicket.PageParameters} argument.
+ * {@link org.apache.wicket.PageParameters} argument.
  * 
  * @author Eelco Hillenius
  */

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/compref/BookmarkablePageLinkPage.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/compref/BookmarkablePageLinkPage.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/compref/BookmarkablePageLinkPage.java?view=diff&rev=527247&p1=incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/compref/BookmarkablePageLinkPage.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/compref/BookmarkablePageLinkPage.java&r2=527247
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/compref/BookmarkablePageLinkPage.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/compref/BookmarkablePageLinkPage.java Tue Apr 10 11:54:24 2007
@@ -14,14 +14,15 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.examples.compref;
+package org.apache.wicket.examples.compref;
+
+import org.apache.wicket.PageParameters;
+import org.apache.wicket.examples.WicketExamplePage;
+import org.apache.wicket.markup.html.link.BookmarkablePageLink;
 
-import wicket.PageParameters;
-import wicket.examples.WicketExamplePage;
-import wicket.markup.html.link.BookmarkablePageLink;
 
 /**
- * Page with examples on {@link wicket.markup.html.link.BookmarkablePageLink}.
+ * Page with examples on {@link org.apache.wicket.markup.html.link.BookmarkablePageLink}.
  * 
  * @author Eelco Hillenius
  */

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/compref/BorderPage.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/compref/BorderPage.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/compref/BorderPage.java?view=diff&rev=527247&p1=incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/compref/BorderPage.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/compref/BorderPage.java&r2=527247
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/compref/BorderPage.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/compref/BorderPage.java Tue Apr 10 11:54:24 2007
@@ -14,13 +14,14 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.examples.compref;
+package org.apache.wicket.examples.compref;
+
+import org.apache.wicket.examples.WicketExamplePage;
+import org.apache.wicket.markup.html.basic.Label;
 
-import wicket.examples.WicketExamplePage;
-import wicket.markup.html.basic.Label;
 
 /**
- * Page with examples on {@link wicket.markup.html.basic.MultiLineLabel}.
+ * Page with examples on {@link org.apache.wicket.markup.html.basic.MultiLineLabel}.
  * 
  * @author Eelco Hillenius
  */

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/compref/ButtonPage.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/compref/ButtonPage.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/compref/ButtonPage.java?view=diff&rev=527247&p1=incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/compref/ButtonPage.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/compref/ButtonPage.java&r2=527247
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/compref/ButtonPage.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/compref/ButtonPage.java Tue Apr 10 11:54:24 2007
@@ -14,15 +14,16 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.examples.compref;
+package org.apache.wicket.examples.compref;
+
+import org.apache.wicket.examples.WicketExamplePage;
+import org.apache.wicket.markup.html.form.Button;
+import org.apache.wicket.markup.html.form.Form;
+import org.apache.wicket.markup.html.panel.FeedbackPanel;
 
-import wicket.examples.WicketExamplePage;
-import wicket.markup.html.form.Button;
-import wicket.markup.html.form.Form;
-import wicket.markup.html.panel.FeedbackPanel;
 
 /**
- * Page with examples on {@link wicket.markup.html.form.Button}.
+ * Page with examples on {@link org.apache.wicket.markup.html.form.Button}.
  * 
  * @author Eelco Hillenius
  */
@@ -74,9 +75,9 @@
 	protected void explain()
 	{
 		String html = " <form wicket:id=\"form\">\n"
-				+ "  <input type=\"submit\" value=\"non wicket submit button\" />\n"
-				+ "  <input wicket:id=\"button1\" type=\"submit\" value=\"default wicket button\" />\n"
-				+ "  <input wicket:id=\"button2\" type=\"submit\" value=\"wicket button with immediate == true\" />\n"
+				+ "  <input type=\"submit\" value=\"non org.apache.wicket submit button\" />\n"
+				+ "  <input wicket:id=\"button1\" type=\"submit\" value=\"default org.apache.wicket button\" />\n"
+				+ "  <input wicket:id=\"button2\" type=\"submit\" value=\"org.apache.wicket button with immediate == true\" />\n"
 				+ " </form>";
 		String code = "&nbsp;&nbsp;&nbsp;&nbsp;// Add a form with an onSubmit implementation that sets a message\n"
 				+ "&nbsp;&nbsp;&nbsp;&nbsp;Form form = new Form(\"form\") {\n"

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/compref/CheckBoxMultipleChoicePage.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/compref/CheckBoxMultipleChoicePage.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/compref/CheckBoxMultipleChoicePage.java?view=diff&rev=527247&p1=incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/compref/CheckBoxMultipleChoicePage.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/compref/CheckBoxMultipleChoicePage.java&r2=527247
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/compref/CheckBoxMultipleChoicePage.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/compref/CheckBoxMultipleChoicePage.java Tue Apr 10 11:54:24 2007
@@ -14,22 +14,23 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.examples.compref;
+package org.apache.wicket.examples.compref;
 
 import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.Iterator;
 import java.util.List;
 
-import wicket.IClusterable;
-import wicket.examples.WicketExamplePage;
-import wicket.markup.html.form.CheckBoxMultipleChoice;
-import wicket.markup.html.form.Form;
-import wicket.markup.html.panel.FeedbackPanel;
-import wicket.model.CompoundPropertyModel;
+import org.apache.wicket.IClusterable;
+import org.apache.wicket.examples.WicketExamplePage;
+import org.apache.wicket.markup.html.form.CheckBoxMultipleChoice;
+import org.apache.wicket.markup.html.form.Form;
+import org.apache.wicket.markup.html.panel.FeedbackPanel;
+import org.apache.wicket.model.CompoundPropertyModel;
+
 
 /**
- * Page with examples on {@link wicket.markup.html.form.CheckBoxMultipleChoice}.
+ * Page with examples on {@link org.apache.wicket.markup.html.form.CheckBoxMultipleChoice}.
  * 
  * @author Igor Vaynberg (ivaynberg)
  */

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/compref/CheckBoxPage.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/compref/CheckBoxPage.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/compref/CheckBoxPage.java?view=diff&rev=527247&p1=incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/compref/CheckBoxPage.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/compref/CheckBoxPage.java&r2=527247
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/compref/CheckBoxPage.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/compref/CheckBoxPage.java Tue Apr 10 11:54:24 2007
@@ -14,17 +14,18 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.examples.compref;
+package org.apache.wicket.examples.compref;
+
+import org.apache.wicket.IClusterable;
+import org.apache.wicket.examples.WicketExamplePage;
+import org.apache.wicket.markup.html.form.CheckBox;
+import org.apache.wicket.markup.html.form.Form;
+import org.apache.wicket.markup.html.panel.FeedbackPanel;
+import org.apache.wicket.model.CompoundPropertyModel;
 
-import wicket.IClusterable;
-import wicket.examples.WicketExamplePage;
-import wicket.markup.html.form.CheckBox;
-import wicket.markup.html.form.Form;
-import wicket.markup.html.panel.FeedbackPanel;
-import wicket.model.CompoundPropertyModel;
 
 /**
- * Page with examples on {@link wicket.markup.html.form.TextArea}.
+ * Page with examples on {@link org.apache.wicket.markup.html.form.TextArea}.
  * 
  * @author Eelco Hillenius
  */

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/compref/CheckGroupPage.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/compref/CheckGroupPage.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/compref/CheckGroupPage.java?view=diff&rev=527247&p1=incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/compref/CheckGroupPage.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/compref/CheckGroupPage.java&r2=527247
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/compref/CheckGroupPage.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/compref/CheckGroupPage.java Tue Apr 10 11:54:24 2007
@@ -14,20 +14,21 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.examples.compref;
+package org.apache.wicket.examples.compref;
 
 import java.util.ArrayList;
 
-import wicket.examples.WicketExamplePage;
-import wicket.markup.html.basic.Label;
-import wicket.markup.html.form.Check;
-import wicket.markup.html.form.CheckGroup;
-import wicket.markup.html.form.CheckGroupSelector;
-import wicket.markup.html.form.Form;
-import wicket.markup.html.list.ListItem;
-import wicket.markup.html.list.ListView;
-import wicket.markup.html.panel.FeedbackPanel;
-import wicket.model.PropertyModel;
+import org.apache.wicket.examples.WicketExamplePage;
+import org.apache.wicket.markup.html.basic.Label;
+import org.apache.wicket.markup.html.form.Check;
+import org.apache.wicket.markup.html.form.CheckGroup;
+import org.apache.wicket.markup.html.form.CheckGroupSelector;
+import org.apache.wicket.markup.html.form.Form;
+import org.apache.wicket.markup.html.list.ListItem;
+import org.apache.wicket.markup.html.list.ListView;
+import org.apache.wicket.markup.html.panel.FeedbackPanel;
+import org.apache.wicket.model.PropertyModel;
+
 
 /**
  * CheckGroup and Check components example page

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/compref/ComponentReferenceApplication.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/compref/ComponentReferenceApplication.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/compref/ComponentReferenceApplication.java?view=diff&rev=527247&p1=incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/compref/ComponentReferenceApplication.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/compref/ComponentReferenceApplication.java&r2=527247
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/compref/ComponentReferenceApplication.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/compref/ComponentReferenceApplication.java Tue Apr 10 11:54:24 2007
@@ -14,12 +14,13 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.examples.compref;
+package org.apache.wicket.examples.compref;
 
 import java.util.ArrayList;
 import java.util.List;
 
-import wicket.examples.WicketExampleApplication;
+import org.apache.wicket.examples.WicketExampleApplication;
+
 
 /**
  * Application class for the component reference.
@@ -54,7 +55,7 @@
 	}
 
 	/**
-	 * @see wicket.examples.WicketExampleApplication#init()
+	 * @see org.apache.wicket.examples.WicketExampleApplication#init()
 	 */
 	protected void init()
 	{
@@ -62,7 +63,7 @@
 	}
 
 	/**
-	 * @see wicket.Application#getHomePage()
+	 * @see org.apache.wicket.Application#getHomePage()
 	 */
 	public Class getHomePage()
 	{

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/compref/DropDownChoicePage.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/compref/DropDownChoicePage.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/compref/DropDownChoicePage.java?view=diff&rev=527247&p1=incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/compref/DropDownChoicePage.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/compref/DropDownChoicePage.java&r2=527247
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/compref/DropDownChoicePage.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/compref/DropDownChoicePage.java Tue Apr 10 11:54:24 2007
@@ -14,21 +14,22 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.examples.compref;
+package org.apache.wicket.examples.compref;
 
 import java.util.Arrays;
 import java.util.List;
 
-import wicket.IClusterable;
-import wicket.examples.WicketExamplePage;
-import wicket.markup.html.form.DropDownChoice;
-import wicket.markup.html.form.Form;
-import wicket.markup.html.form.IChoiceRenderer;
-import wicket.markup.html.panel.FeedbackPanel;
-import wicket.model.CompoundPropertyModel;
+import org.apache.wicket.IClusterable;
+import org.apache.wicket.examples.WicketExamplePage;
+import org.apache.wicket.markup.html.form.DropDownChoice;
+import org.apache.wicket.markup.html.form.Form;
+import org.apache.wicket.markup.html.form.IChoiceRenderer;
+import org.apache.wicket.markup.html.panel.FeedbackPanel;
+import org.apache.wicket.model.CompoundPropertyModel;
+
 
 /**
- * Page with examples on {@link wicket.markup.html.form.DropDownChoice}.
+ * Page with examples on {@link org.apache.wicket.markup.html.form.DropDownChoice}.
  * 
  * @author Eelco Hillenius
  */
@@ -89,7 +90,7 @@
 			/**
 			 * Gets the display value that is visible to the end user.
 			 * 
-			 * @see wicket.markup.html.form.IChoiceRenderer#getDisplayValue(java.lang.Object)
+			 * @see org.apache.wicket.markup.html.form.IChoiceRenderer#getDisplayValue(java.lang.Object)
 			 */
 			public Object getDisplayValue(Object object)
 			{
@@ -119,7 +120,7 @@
 			 * Gets the value that is invisble to the end user, and that is used
 			 * as the selection id.
 			 * 
-			 * @see wicket.markup.html.form.IChoiceRenderer#getIdValue(java.lang.Object,
+			 * @see org.apache.wicket.markup.html.form.IChoiceRenderer#getIdValue(java.lang.Object,
 			 *      int)
 			 */
 			public String getIdValue(Object object, int index)

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/compref/ExplainPanel.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/compref/ExplainPanel.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/compref/ExplainPanel.java?view=diff&rev=527247&p1=incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/compref/ExplainPanel.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/compref/ExplainPanel.java&r2=527247
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/compref/ExplainPanel.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/compref/ExplainPanel.java Tue Apr 10 11:54:24 2007
@@ -14,10 +14,10 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.examples.compref;
+package org.apache.wicket.examples.compref;
 
-import wicket.markup.html.basic.MultiLineLabel;
-import wicket.markup.html.panel.Panel;
+import org.apache.wicket.markup.html.basic.MultiLineLabel;
+import org.apache.wicket.markup.html.panel.Panel;
 
 /**
  * A explanation panel component.

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/compref/ExternalLinkPage.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/compref/ExternalLinkPage.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/compref/ExternalLinkPage.java?view=diff&rev=527247&p1=incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/compref/ExternalLinkPage.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/compref/ExternalLinkPage.java&r2=527247
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/compref/ExternalLinkPage.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/compref/ExternalLinkPage.java Tue Apr 10 11:54:24 2007
@@ -14,13 +14,14 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.examples.compref;
+package org.apache.wicket.examples.compref;
+
+import org.apache.wicket.examples.WicketExamplePage;
+import org.apache.wicket.markup.html.link.ExternalLink;
 
-import wicket.examples.WicketExamplePage;
-import wicket.markup.html.link.ExternalLink;
 
 /**
- * Page with examples on {@link wicket.markup.html.link.ExternalLink}.
+ * Page with examples on {@link org.apache.wicket.markup.html.link.ExternalLink}.
  * 
  * @author Eelco Hillenius
  */

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/compref/FormPage.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/compref/FormPage.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/compref/FormPage.java?view=diff&rev=527247&p1=incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/compref/FormPage.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/compref/FormPage.java&r2=527247
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/compref/FormPage.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/compref/FormPage.java Tue Apr 10 11:54:24 2007
@@ -14,14 +14,15 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.examples.compref;
+package org.apache.wicket.examples.compref;
+
+import org.apache.wicket.examples.WicketExamplePage;
+import org.apache.wicket.markup.html.form.Form;
+import org.apache.wicket.markup.html.panel.FeedbackPanel;
 
-import wicket.examples.WicketExamplePage;
-import wicket.markup.html.form.Form;
-import wicket.markup.html.panel.FeedbackPanel;
 
 /**
- * Page with examples on {@link wicket.markup.html.form.Form}.
+ * Page with examples on {@link org.apache.wicket.markup.html.form.Form}.
  * 
  * @author Eelco Hillenius
  */

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/compref/FragmentPage.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/compref/FragmentPage.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/compref/FragmentPage.java?view=diff&rev=527247&p1=incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/compref/FragmentPage.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/compref/FragmentPage.java&r2=527247
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/compref/FragmentPage.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/compref/FragmentPage.java Tue Apr 10 11:54:24 2007
@@ -14,14 +14,15 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.examples.compref;
+package org.apache.wicket.examples.compref;
+
+import org.apache.wicket.examples.WicketExamplePage;
+import org.apache.wicket.markup.html.basic.Label;
+import org.apache.wicket.markup.html.panel.Fragment;
 
-import wicket.examples.WicketExamplePage;
-import wicket.markup.html.basic.Label;
-import wicket.markup.html.panel.Fragment;
 
 /**
- * Page with examples on {@link wicket.markup.html.panel.Fragment}.
+ * Page with examples on {@link org.apache.wicket.markup.html.panel.Fragment}.
  * 
  * @author Eelco Hillenius
  */
@@ -58,7 +59,7 @@
 
 	protected void explain()
 	{
-		String html = "<wicket:fragment wicket:id=\"fragmentid\">...</wicket:fragment>";
+		String html = "<org.apache.wicket:fragment wicket:id=\"fragmentid\">...</org.apache.wicket:fragment>";
 		String code = "private class MyFragment extends Fragment {\n ...\n"
 				+ "add(new MyFragment(\"fragment\", \"fragmentid\"));";
 		add(new ExplainPanel(html, code));

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/compref/IncludePage.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/compref/IncludePage.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/compref/IncludePage.java?view=diff&rev=527247&p1=incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/compref/IncludePage.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/compref/IncludePage.java&r2=527247
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/compref/IncludePage.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/compref/IncludePage.java Tue Apr 10 11:54:24 2007
@@ -14,13 +14,14 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.examples.compref;
+package org.apache.wicket.examples.compref;
+
+import org.apache.wicket.examples.WicketExamplePage;
+import org.apache.wicket.markup.html.include.Include;
 
-import wicket.examples.WicketExamplePage;
-import wicket.markup.html.include.Include;
 
 /**
- * Page with examples on {@link wicket.markup.html.basic.MultiLineLabel}.
+ * Page with examples on {@link org.apache.wicket.markup.html.basic.MultiLineLabel}.
  * 
  * @author Eelco Hillenius
  */

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/compref/Index.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/compref/Index.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/compref/Index.java?view=diff&rev=527247&p1=incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/compref/Index.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/compref/Index.java&r2=527247
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/compref/Index.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/compref/Index.java Tue Apr 10 11:54:24 2007
@@ -14,9 +14,9 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.examples.compref;
+package org.apache.wicket.examples.compref;
 
-import wicket.examples.WicketExamplePage;
+import org.apache.wicket.examples.WicketExamplePage;
 
 /**
  * Home page of the component reference example.

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/compref/LabelPage.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/compref/LabelPage.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/compref/LabelPage.java?view=diff&rev=527247&p1=incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/compref/LabelPage.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/compref/LabelPage.java&r2=527247
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/compref/LabelPage.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/compref/LabelPage.java Tue Apr 10 11:54:24 2007
@@ -14,18 +14,18 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.examples.compref;
+package org.apache.wicket.examples.compref;
 
 import java.util.Date;
 
-import wicket.Component;
-import wicket.examples.WicketExamplePage;
-import wicket.markup.html.basic.Label;
-import wicket.model.Model;
-import wicket.model.StringResourceModel;
+import org.apache.wicket.examples.WicketExamplePage;
+import org.apache.wicket.markup.html.basic.Label;
+import org.apache.wicket.model.Model;
+import org.apache.wicket.model.StringResourceModel;
+
 
 /**
- * Page with examples on {@link wicket.markup.html.basic.Label}.
+ * Page with examples on {@link org.apache.wicket.markup.html.basic.Label}.
  * 
  * @author Eelco Hillenius
  */

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/compref/LinkPage.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/compref/LinkPage.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/compref/LinkPage.java?view=diff&rev=527247&p1=incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/compref/LinkPage.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/compref/LinkPage.java&r2=527247
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/compref/LinkPage.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/compref/LinkPage.java Tue Apr 10 11:54:24 2007
@@ -14,18 +14,18 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.examples.compref;
+package org.apache.wicket.examples.compref;
+
+import org.apache.wicket.AttributeModifier;
+import org.apache.wicket.IClusterable;
+import org.apache.wicket.examples.WicketExamplePage;
+import org.apache.wicket.markup.html.basic.Label;
+import org.apache.wicket.markup.html.link.Link;
+import org.apache.wicket.model.Model;
 
-import wicket.AttributeModifier;
-import wicket.Component;
-import wicket.IClusterable;
-import wicket.examples.WicketExamplePage;
-import wicket.markup.html.basic.Label;
-import wicket.markup.html.link.Link;
-import wicket.model.Model;
 
 /**
- * Page with examples on {@link wicket.markup.html.link.Link}.
+ * Page with examples on {@link org.apache.wicket.markup.html.link.Link}.
  * 
  * @author Eelco Hillenius
  */

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/compref/ListChoicePage.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/compref/ListChoicePage.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/compref/ListChoicePage.java?view=diff&rev=527247&p1=incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/compref/ListChoicePage.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/compref/ListChoicePage.java&r2=527247
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/compref/ListChoicePage.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/compref/ListChoicePage.java Tue Apr 10 11:54:24 2007
@@ -14,20 +14,21 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.examples.compref;
+package org.apache.wicket.examples.compref;
 
 import java.util.Arrays;
 import java.util.List;
 
-import wicket.IClusterable;
-import wicket.examples.WicketExamplePage;
-import wicket.markup.html.form.Form;
-import wicket.markup.html.form.ListChoice;
-import wicket.markup.html.panel.FeedbackPanel;
-import wicket.model.CompoundPropertyModel;
+import org.apache.wicket.IClusterable;
+import org.apache.wicket.examples.WicketExamplePage;
+import org.apache.wicket.markup.html.form.Form;
+import org.apache.wicket.markup.html.form.ListChoice;
+import org.apache.wicket.markup.html.panel.FeedbackPanel;
+import org.apache.wicket.model.CompoundPropertyModel;
+
 
 /**
- * Page with examples on {@link wicket.markup.html.form.ListChoice}.
+ * Page with examples on {@link org.apache.wicket.markup.html.form.ListChoice}.
  * 
  * @author Eelco Hillenius
  */

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/compref/ListMultipleChoicePage.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/compref/ListMultipleChoicePage.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/compref/ListMultipleChoicePage.java?view=diff&rev=527247&p1=incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/compref/ListMultipleChoicePage.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/compref/ListMultipleChoicePage.java&r2=527247
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/compref/ListMultipleChoicePage.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/compref/ListMultipleChoicePage.java Tue Apr 10 11:54:24 2007
@@ -14,22 +14,23 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.examples.compref;
+package org.apache.wicket.examples.compref;
 
 import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.Iterator;
 import java.util.List;
 
-import wicket.IClusterable;
-import wicket.examples.WicketExamplePage;
-import wicket.markup.html.form.Form;
-import wicket.markup.html.form.ListMultipleChoice;
-import wicket.markup.html.panel.FeedbackPanel;
-import wicket.model.CompoundPropertyModel;
+import org.apache.wicket.IClusterable;
+import org.apache.wicket.examples.WicketExamplePage;
+import org.apache.wicket.markup.html.form.Form;
+import org.apache.wicket.markup.html.form.ListMultipleChoice;
+import org.apache.wicket.markup.html.panel.FeedbackPanel;
+import org.apache.wicket.model.CompoundPropertyModel;
+
 
 /**
- * Page with examples on {@link wicket.markup.html.form.ListMultipleChoice}.
+ * Page with examples on {@link org.apache.wicket.markup.html.form.ListMultipleChoice}.
  * 
  * @author Eelco Hillenius
  */

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/compref/MultiLineLabelPage.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/compref/MultiLineLabelPage.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/compref/MultiLineLabelPage.java?view=diff&rev=527247&p1=incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/compref/MultiLineLabelPage.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/compref/MultiLineLabelPage.java&r2=527247
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/compref/MultiLineLabelPage.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/compref/MultiLineLabelPage.java Tue Apr 10 11:54:24 2007
@@ -14,13 +14,14 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.examples.compref;
+package org.apache.wicket.examples.compref;
+
+import org.apache.wicket.examples.WicketExamplePage;
+import org.apache.wicket.markup.html.basic.MultiLineLabel;
 
-import wicket.examples.WicketExamplePage;
-import wicket.markup.html.basic.MultiLineLabel;
 
 /**
- * Page with examples on {@link wicket.markup.html.basic.MultiLineLabel}.
+ * Page with examples on {@link org.apache.wicket.markup.html.basic.MultiLineLabel}.
  * 
  * @author Eelco Hillenius
  */

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/compref/MyBorder.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/compref/MyBorder.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/compref/MyBorder.java?view=diff&rev=527247&p1=incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/compref/MyBorder.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/compref/MyBorder.java&r2=527247
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/compref/MyBorder.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/compref/MyBorder.java Tue Apr 10 11:54:24 2007
@@ -14,9 +14,9 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.examples.compref;
+package org.apache.wicket.examples.compref;
 
-import wicket.markup.html.border.Border;
+import org.apache.wicket.markup.html.border.Border;
 
 /**
  * A sample panel component.

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/compref/MyPanel.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/compref/MyPanel.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/compref/MyPanel.java?view=diff&rev=527247&p1=incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/compref/MyPanel.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/compref/MyPanel.java&r2=527247
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/compref/MyPanel.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/compref/MyPanel.java Tue Apr 10 11:54:24 2007
@@ -14,10 +14,10 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.examples.compref;
+package org.apache.wicket.examples.compref;
 
-import wicket.markup.html.basic.Label;
-import wicket.markup.html.panel.Panel;
+import org.apache.wicket.markup.html.basic.Label;
+import org.apache.wicket.markup.html.panel.Panel;
 
 /**
  * A sample panel component.

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/compref/NonBookmarkablePage.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/compref/NonBookmarkablePage.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/compref/NonBookmarkablePage.java?view=diff&rev=527247&p1=incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/compref/NonBookmarkablePage.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/compref/NonBookmarkablePage.java&r2=527247
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/compref/NonBookmarkablePage.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/compref/NonBookmarkablePage.java Tue Apr 10 11:54:24 2007
@@ -14,15 +14,15 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.examples.compref;
+package org.apache.wicket.examples.compref;
 
-import wicket.markup.html.WebPage;
-import wicket.markup.html.link.PageLink;
+import org.apache.wicket.markup.html.WebPage;
+import org.apache.wicket.markup.html.link.PageLink;
 
 /**
  * Example page that cannot be bookmarked. A page is bookmarkable when it has a
  * public default constructor and/or a constructor with a
- * {@link wicket.PageParameters} argument.
+ * {@link org.apache.wicket.PageParameters} argument.
  * 
  * @author Eelco Hillenius
  */

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/compref/PageLinkPage.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/compref/PageLinkPage.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/compref/PageLinkPage.java?view=diff&rev=527247&p1=incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/compref/PageLinkPage.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/compref/PageLinkPage.java&r2=527247
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/compref/PageLinkPage.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/compref/PageLinkPage.java Tue Apr 10 11:54:24 2007
@@ -14,15 +14,16 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.examples.compref;
+package org.apache.wicket.examples.compref;
+
+import org.apache.wicket.Page;
+import org.apache.wicket.examples.WicketExamplePage;
+import org.apache.wicket.markup.html.link.IPageLink;
+import org.apache.wicket.markup.html.link.PageLink;
 
-import wicket.Page;
-import wicket.examples.WicketExamplePage;
-import wicket.markup.html.link.IPageLink;
-import wicket.markup.html.link.PageLink;
 
 /**
- * Page with examples on {@link wicket.markup.html.link.PageLink}.
+ * Page with examples on {@link org.apache.wicket.markup.html.link.PageLink}.
  * 
  * @author Eelco Hillenius
  */

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/compref/PalettePage.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/compref/PalettePage.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/compref/PalettePage.java?view=diff&rev=527247&p1=incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/compref/PalettePage.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/compref/PalettePage.java&r2=527247
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/compref/PalettePage.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/compref/PalettePage.java Tue Apr 10 11:54:24 2007
@@ -14,19 +14,20 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.examples.compref;
+package org.apache.wicket.examples.compref;
 
 import java.io.Serializable;
 import java.util.ArrayList;
 import java.util.List;
 
-import wicket.examples.WicketExamplePage;
-import wicket.extensions.markup.html.form.palette.Palette;
-import wicket.markup.html.form.ChoiceRenderer;
-import wicket.markup.html.form.Form;
-import wicket.markup.html.form.IChoiceRenderer;
-import wicket.markup.html.panel.FeedbackPanel;
-import wicket.model.Model;
+import org.apache.wicket.examples.WicketExamplePage;
+import org.apache.wicket.extensions.markup.html.form.palette.Palette;
+import org.apache.wicket.markup.html.form.ChoiceRenderer;
+import org.apache.wicket.markup.html.form.Form;
+import org.apache.wicket.markup.html.form.IChoiceRenderer;
+import org.apache.wicket.markup.html.panel.FeedbackPanel;
+import org.apache.wicket.model.Model;
+
 
 /**
  * Palette component example

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/compref/PanelPage.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/compref/PanelPage.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/compref/PanelPage.java?view=diff&rev=527247&p1=incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/compref/PanelPage.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/compref/PanelPage.java&r2=527247
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/compref/PanelPage.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/compref/PanelPage.java Tue Apr 10 11:54:24 2007
@@ -14,12 +14,12 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.examples.compref;
+package org.apache.wicket.examples.compref;
 
-import wicket.examples.WicketExamplePage;
+import org.apache.wicket.examples.WicketExamplePage;
 
 /**
- * Page with examples on {@link wicket.markup.html.panel.Panel}.
+ * Page with examples on {@link org.apache.wicket.markup.html.panel.Panel}.
  * 
  * @author Eelco Hillenius
  */

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/compref/Person.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/compref/Person.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/compref/Person.java?view=diff&rev=527247&p1=incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/compref/Person.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/compref/Person.java&r2=527247
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/compref/Person.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/compref/Person.java Tue Apr 10 11:54:24 2007
@@ -14,11 +14,12 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.examples.compref;
+package org.apache.wicket.examples.compref;
 
 import java.util.Date;
 
-import wicket.IClusterable;
+import org.apache.wicket.IClusterable;
+
 
 /**
  * A person.

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/compref/RadioChoicePage.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/compref/RadioChoicePage.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/compref/RadioChoicePage.java?view=diff&rev=527247&p1=incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/compref/RadioChoicePage.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/compref/RadioChoicePage.java&r2=527247
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/compref/RadioChoicePage.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/compref/RadioChoicePage.java Tue Apr 10 11:54:24 2007
@@ -14,20 +14,21 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.examples.compref;
+package org.apache.wicket.examples.compref;
 
 import java.util.Arrays;
 import java.util.List;
 
-import wicket.IClusterable;
-import wicket.examples.WicketExamplePage;
-import wicket.markup.html.form.Form;
-import wicket.markup.html.form.RadioChoice;
-import wicket.markup.html.panel.FeedbackPanel;
-import wicket.model.CompoundPropertyModel;
+import org.apache.wicket.IClusterable;
+import org.apache.wicket.examples.WicketExamplePage;
+import org.apache.wicket.markup.html.form.Form;
+import org.apache.wicket.markup.html.form.RadioChoice;
+import org.apache.wicket.markup.html.panel.FeedbackPanel;
+import org.apache.wicket.model.CompoundPropertyModel;
+
 
 /**
  * Page with examples on {@link wicket.markup.html.form.ListChoice}.
  * 
  * @author Eelco Hillenius
  */
@@ -14,20 +14,21 @@
 
 /**
- * Page with examples on {@link wicket.markup.html.form.ListChoice}.
+ * Page with examples on {@link org.apache.wicket.markup.html.form.ListChoice}.
  * 
  * @author Eelco Hillenius